@@ -4,11 +4,11 @@ TEST_ROOT = os.path.abspath(os.path.dirname(__file__))
 DATABASE_ENGINE = 'sqlite3'
 DATABASE_NAME = 'mediasynctest.db'
 
-MEDIA_ROOT = os.path.join(TEST_ROOT, 'media')
-MEDIA_URL = '/media/'
+STATIC_ROOT = os.path.join(TEST_ROOT, 'media')
+STATIC_URL = '/media/'
 
 MEDIASYNC = {
     'BACKEND': 'mediasync.backends.dummy',
 }
 
-INSTALLED_APPS = ('mediasync.tests',)
\ No newline at end of file
+INSTALLED_APPS = ('mediasync.tests',)
